# 6. Postface  
## References  
SMARTS:  
[https://www.daylight.com/dayhtml/doc/theory/theory.smarts.html](https://www.daylight.com/dayhtml/doc/theory/theory.smarts.html)  

SMARTS Tutorial:  
[https://www.daylight.com/dayhtml_tutorials/languages/smarts/](https://www.daylight.com/dayhtml_tutorials/languages/smarts/)  

SMARTS Examples:  
[https://www.daylight.com/dayhtml_tutorials/languages/smarts/smarts_examples.html](https://www.daylight.com/dayhtml_tutorials/languages/smarts/smarts_examples.html)  

SMILES:  
[https://doi.org/10.1021/ci00057a005](https://doi.org/10.1021/ci00057a005)  

At the beginning of the project, I frequently referred to the URL below.  
[https://future-chem.com/rdkit-chemical-rxn/](https://future-chem.com/rdkit-chemical-rxn/)  

## For future works  
An example of polymerization via non-classical carobocation.  
[https://doi.org/10.1295/koron.2015-0011](https://doi.org/10.1295/koron.2015-0011)  